@@ -8,7 +8,6 @@ import (
 
 	"github.com/hetznercloud/cli/internal/cmd/base"
 	"github.com/hetznercloud/cli/internal/cmd/cmpl"
-	"github.com/hetznercloud/cli/internal/cmd/experimental"
 	"github.com/hetznercloud/cli/internal/cmd/util"
 	"github.com/hetznercloud/cli/internal/hcapi2"
 	"github.com/hetznercloud/cli/internal/state"
@@ -144,7 +143,6 @@ var CreateCmd = base.CreateCmd[*hcloud.StorageBox]{
 		cmd.Printf("Server: %s\n", storageBox.Server)
 		cmd.Printf("Username: %s\n", storageBox.Username)
 	},
-	Experimental: experimental.StorageBoxes,
 }
 
 // resolveSSHKey resolves the given pubKey by doing the following:
