@@ -39,6 +39,6 @@ func TestRollbackSnapshot(t *testing.T) {
 	out, errOut, err := fx.Run(cmd, args)
 
 	require.NoError(t, err)
-	assert.Equal(t, ExperimentalWarning, errOut)
+	assert.Empty(t, errOut)
 	assert.Equal(t, "Rolled back Storage Box 123 to Snapshot 456\n", out)
 }
